# SOTOOLE_2020B
Software Support Project for Simple Spectra Viewer

Initialised as an effective fork of https://dev.aao.org.au/datacentral/common/dcspectra

TESTS
-----
1. tox
2. source use_cases/MarzV3/run_tdd.sh
3. ./use_cases/pytest_tdd/run_tdd.sh
